@@ -9,12 +9,12 @@
 
 namespace apolloron {
 
-#define UTF8_GB18030_TABLE_MAX 8678
+#define UTF8_GB18030_TABLE_MAX 231
 
 typedef struct {
     const char *utf8;
     const char *gb18030;
-    unsigned char count;
+    unsigned int count;
 } T_UTF8_GB18030;
 
 extern const T_UTF8_GB18030 utf8_gb18030[UTF8_GB18030_TABLE_MAX];
